============================
Djblets 0.7.32 Release Notes
============================

**Release date**: February 21, 2016


djblets.siteconfig
==================

* Improved the extensibility of some of the siteconfig templates.


Contributors
============

* Christian Hammond
* David Trowbridge
